Status

Enum Status 

pub enum Status {
    Static,
    Smoothing,
    InTouch,
}
The current state of scrolling.

There are two important types of scroll input deviced:

  • Discreen scroll wheels on a mouse
  • Smooth scroll input from a trackpad

Scroll wheels will usually fire one single scroll event, so it is important that egui smooths it out over time.

On the contrary, trackpads usually provide smooth scroll input, and with kinetic scrolling (which on Mac is implemented by the OS) scroll events can arrive after the user lets go of the trackpad.

In either case, we consider use to be scrolling until there is no more scroll events expected.

This means there are a few different states we can be in:

  • Not scrolling
  • “Smooth scrolling” (low-pass filter of discreet scroll events)
  • Trackpad-scrolling (we receive begin/end phases for these)

Variants



Static

Not scrolling,



Smoothing

We’re smoothing out previous scroll events



InTouch