WheelState

Struct WheelState 

pub struct WheelState {
    pub status: Status,
    pub modifiers: Modifiers,
    pub last_wheel_event: f64,
    pub unprocessed_wheel_delta: Vec2,
    pub smooth_wheel_delta: Vec2,
}
Keeps track of wheel (scroll) input.

Fields

status: Status

Are we currently in a scroll action?

This may be true even if no scroll events came in this frame, but we are in a kinetic scroll or in a smoothed scroll.

modifiers: Modifiers

The modifiers at the start of the scroll.

last_wheel_event: f64

Time of the last scroll event.

unprocessed_wheel_delta: Vec2

Used for smoothing the scroll delta.

smooth_wheel_delta: Vec2

How many points the user scrolled, smoothed over a few frames.

The delta dictates how the content should move.

A positive X-value indicates the content is being moved right, as when swiping right on a touch-screen or track-pad with natural scrolling.

A positive Y-value indicates the content is being moved down, as when swiping down on a touch-screen or track-pad with natural scrolling.

crate::ScrollArea will both read and write to this field, so that at the end of the frame this will be zero if a scroll-area consumed the delta.

Implementations

Source

impl WheelState

pub fn on_wheel_event( &mut self, viewport_rect: Rect, options: &InputOptions, time: f64, unit: MouseWheelUnit, delta: Vec2, phase: TouchPhase, latest_modifiers: Modifiers, )

pub fn after_events(&mut self, time: f64, dt: f32)

pub fn is_scrolling(&self) -> bool

True if there is an active scroll action that might scroll more when using Self::smooth_wheel_delta.

pub fn ui(&self, ui: &mut Ui)